@@ -8,8 +8,8 @@ pub enum Value {
     #[tag("SimpleBlock")]
     SimpleBlock(SimpleBlock),
 
-    #[tag("UnitValue")]
-    Unit(UnitValue),
+    #[tag("Dimension")]
+    Dimension(Dimension),
 
     #[tag("Number")]
     Number(Number),
@@ -20,8 +20,8 @@ pub enum Value {
     #[tag("Ratio")]
     Ratio(Ratio),
 
-    #[tag("HashValue")]
-    Hash(HashValue),
+    #[tag("Color")]
+    Color(Color),
 
     #[tag("Ident")]
     Ident(Ident),
@@ -84,8 +84,15 @@ pub struct Function {
     pub value: Vec<Value>,
 }
 
-#[ast_node("HashValue")]
-pub struct HashValue {
+#[ast_node]
+pub enum Color {
+    // TODO more
+    #[tag("HexColor")]
+    HexColor(HexColor),
+}
+
+#[ast_node("HexColor")]
+pub struct HexColor {
     /// Includes `#`
     pub span: Span,
     /// Does **not** include `#`
@@ -94,18 +101,11 @@ pub struct HashValue {
     pub raw: JsWord,
 }
 
-#[ast_node]
-pub struct Unit {
-    pub span: Span,
-    pub value: JsWord,
-    pub raw: JsWord,
-}
-
-#[ast_node("UnitValue")]
-pub struct UnitValue {
+#[ast_node("Dimension")]
+pub struct Dimension {
     pub span: Span,
     pub value: Number,
-    pub unit: Unit,
+    pub unit: Ident,
 }
 
 #[ast_node("Percent")]
